@@ -35,9 +35,7 @@
 #include <gio/gio.h>
 #include <stdlib.h>
 #include <gtk/gtk.h>
-#ifdef HAVE_VTE
 #include <vte/vte.h>
-#endif
 #include <canberra-gtk.h>
 
 #include "gcm-calibrate-argyll.h"
@@ -45,15 +43,10 @@
 #include "gcm-utils.h"
 #include "gcm-screen.h"
 #include "gcm-print.h"
-#include "gcm-xyz.h"
 #include "gcm-calibrate-dialog.h"
 
 #include "egg-debug.h"
 
-#define FIXED_ARGYLL
-
-//#define USE_DOUBLE_DENSITY
-
 static void     gcm_calibrate_argyll_finalize	(GObject     *object);
 
 #define GCM_CALIBRATE_ARGYLL_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GCM_TYPE_CALIBRATE_ARGYLL, GcmCalibrateArgyllPrivate))
@@ -83,12 +76,9 @@ struct _GcmCalibrateArgyllPrivate
 	glong				 vte_previous_row;
 	glong				 vte_previous_col;
 	gboolean			 already_on_window;
-	gboolean			 done_calibrate;
 	GcmCalibrateArgyllState		 state;
 	GcmPrint			*print;
 	const gchar			*argyllcms_ok;
-	gboolean			 done_spot_read;
-	guint				 keypress_id;
 };
 
 enum {
@@ -174,18 +164,15 @@ gcm_calibrate_argyll_printer_get_patches (GcmCalibrateArgyll *calibrate_argyll)
 	else if (precision == GCM_CALIBRATE_PRECISION_LONG)
 		patches = 360;
 
-#ifdef USE_DOUBLE_DENSITY
 	/* using double density, so we can double the patch count */
 	if (colorimeter_kind == GCM_COLORIMETER_KIND_COLOR_MUNKI ||
 	    colorimeter_kind == GCM_COLORIMETER_KIND_SPECTRO_SCAN) {
 		patches *= 2;
 	}
-#endif
 
 	return patches;
 }
 
-#ifdef HAVE_VTE
 /**
  * gcm_calibrate_argyll_get_colorimeter_image_attach:
  **/
@@ -235,7 +222,6 @@ gcm_calibrate_argyll_get_colorimeter_image_screen (GcmCalibrateArgyll *calibrate
 		return "munki-screen.svg";
 	return NULL;
 }
-#endif
 
 /**
  * gcm_calibrate_argyll_get_display:
@@ -369,7 +355,6 @@ static gboolean
 gcm_calibrate_argyll_fork_command (GcmCalibrateArgyll *calibrate_argyll, gchar **argv, GError **error)
 {
 	gboolean ret = FALSE;
-#ifdef HAVE_VTE
 	const gchar *envp[] = { "ARGYLL_NOT_INTERACTIVE", NULL };
 	const gchar *working_directory;
 	GcmCalibrateArgyllPrivate *priv = calibrate_argyll->priv;
@@ -384,11 +369,7 @@ gcm_calibrate_argyll_fork_command (GcmCalibrateArgyll *calibrate_argyll, gchar *
 					      VTE_PTY_DEFAULT,
 					      working_directory,
 					      argv, (gchar**)envp,
-#ifdef FIXED_ARGYLL
-					      0,
-#else
 					      G_SPAWN_FILE_AND_ARGV_ZERO,
-#endif
 					      NULL, NULL,
 					      &priv->child_pid, error);
 	if (!ret)
@@ -397,7 +378,6 @@ gcm_calibrate_argyll_fork_command (GcmCalibrateArgyll *calibrate_argyll, gchar *
 	/* we're running */
 	priv->state = GCM_CALIBRATE_ARGYLL_STATE_RUNNING;
 out:
-#endif
 	return ret;
 }
 
@@ -464,10 +444,7 @@ gcm_calibrate_argyll_display_neutralise (GcmCalibrateArgyll *calibrate_argyll, G
 	array = g_ptr_array_new_with_free_func (g_free);
 
 	/* setup the command */
-#ifdef FIXED_ARGYLL
-	g_ptr_array_add (array, g_strdup (command));
-#endif
-	g_ptr_array_add (array, g_strdup ("-v"));
+	g_ptr_array_add (array, g_strdup ("-v9"));
 	g_ptr_array_add (array, g_strdup ("-ql"));
 	g_ptr_array_add (array, g_strdup ("-m"));
 	g_ptr_array_add (array, g_strdup_printf ("-d%i", priv->display));
@@ -494,7 +471,6 @@ gcm_calibrate_argyll_display_neutralise (GcmCalibrateArgyll *calibrate_argyll, G
 		ret = FALSE;
 		goto out;
 	}
-#ifdef HAVE_VTE
 	if (priv->response == GTK_RESPONSE_REJECT) {
 		gchar *vte_text;
 		vte_text = vte_terminal_get_text (VTE_TERMINAL(priv->terminal), NULL, NULL, NULL);
@@ -506,7 +482,6 @@ gcm_calibrate_argyll_display_neutralise (GcmCalibrateArgyll *calibrate_argyll, G
 		ret = FALSE;
 		goto out;
 	}
-#endif
 out:
 	if (array != NULL)
 		g_ptr_array_unref (array);
@@ -559,12 +534,7 @@ gcm_calibrate_argyll_display_read_chart (GcmCalibrateArgyll *calibrate_argyll, G
 	array = g_ptr_array_new_with_free_func (g_free);
 
 	/* setup the command */
-#ifdef FIXED_ARGYLL
-	g_ptr_array_add (array, g_strdup (command));
-#endif
-	g_ptr_array_add (array, g_strdup ("-v"));
-	if (priv->done_calibrate)
-		g_ptr_array_add (array, g_strdup ("-N"));
+	g_ptr_array_add (array, g_strdup ("-v9"));
 	g_ptr_array_add (array, g_strdup (basename));
 	argv = gcm_utils_ptr_array_to_strv (array);
 	gcm_calibrate_argyll_debug_argv (command, argv);
@@ -586,7 +556,6 @@ gcm_calibrate_argyll_display_read_chart (GcmCalibrateArgyll *calibrate_argyll, G
 		ret = FALSE;
 		goto out;
 	}
-#ifdef HAVE_VTE
 	if (priv->response == GTK_RESPONSE_REJECT) {
 		gchar *vte_text;
 		vte_text = vte_terminal_get_text (VTE_TERMINAL(priv->terminal), NULL, NULL, NULL);
@@ -598,7 +567,6 @@ gcm_calibrate_argyll_display_read_chart (GcmCalibrateArgyll *calibrate_argyll, G
 		ret = FALSE;
 		goto out;
 	}
-#endif
 out:
 	if (array != NULL)
 		g_ptr_array_unref (array);
@@ -651,10 +619,7 @@ gcm_calibrate_argyll_display_generate_patches (GcmCalibrateArgyll *calibrate_arg
 	array = g_ptr_array_new_with_free_func (g_free);
 
 	/* setup the command */
-#ifdef FIXED_ARGYLL
-	g_ptr_array_add (array, g_strdup (command));
-#endif
-	g_ptr_array_add (array, g_strdup ("-v"));
+	g_ptr_array_add (array, g_strdup ("-v9"));
 	if (device_kind == GCM_DEVICE_KIND_PRINTER) {
 		/* print RGB */
 		g_ptr_array_add (array, g_strdup ("-d2"));
@@ -693,7 +658,6 @@ gcm_calibrate_argyll_display_generate_patches (GcmCalibrateArgyll *calibrate_arg
 		ret = FALSE;
 		goto out;
 	}
-#ifdef HAVE_VTE
 	if (priv->response == GTK_RESPONSE_REJECT) {
 		gchar *vte_text;
 		vte_text = vte_terminal_get_text (VTE_TERMINAL(priv->terminal), NULL, NULL, NULL);
@@ -705,7 +669,6 @@ gcm_calibrate_argyll_display_generate_patches (GcmCalibrateArgyll *calibrate_arg
 		ret = FALSE;
 		goto out;
 	}
-#endif
 out:
 	if (array != NULL)
 		g_ptr_array_unref (array);
@@ -760,10 +723,7 @@ gcm_calibrate_argyll_display_draw_and_measure (GcmCalibrateArgyll *calibrate_arg
 	array = g_ptr_array_new_with_free_func (g_free);
 
 	/* setup the command */
-#ifdef FIXED_ARGYLL
-	g_ptr_array_add (array, g_strdup (command));
-#endif
-	g_ptr_array_add (array, g_strdup ("-v"));
+	g_ptr_array_add (array, g_strdup ("-v9"));
 	g_ptr_array_add (array, g_strdup_printf ("-d%i", priv->display));
 	g_ptr_array_add (array, g_strdup_printf ("-y%c", kind));
 	g_ptr_array_add (array, g_strdup ("-k"));
@@ -789,7 +749,6 @@ gcm_calibrate_argyll_display_draw_and_measure (GcmCalibrateArgyll *calibrate_arg
 		ret = FALSE;
 		goto out;
 	}
-#ifdef HAVE_VTE
 	if (priv->response == GTK_RESPONSE_REJECT) {
 		gchar *vte_text;
 		vte_text = vte_terminal_get_text (VTE_TERMINAL(priv->terminal), NULL, NULL, NULL);
@@ -801,7 +760,6 @@ gcm_calibrate_argyll_display_draw_and_measure (GcmCalibrateArgyll *calibrate_arg
 		ret = FALSE;
 		goto out;
 	}
-#endif
 out:
 	if (array != NULL)
 		g_ptr_array_unref (array);
@@ -875,10 +833,7 @@ gcm_calibrate_argyll_display_generate_profile (GcmCalibrateArgyll *calibrate_arg
 	array = g_ptr_array_new_with_free_func (g_free);
 
 	/* setup the command */
-#ifdef FIXED_ARGYLL
-	g_ptr_array_add (array, g_strdup (command));
-#endif
-	g_ptr_array_add (array, g_strdup ("-v"));
+	g_ptr_array_add (array, g_strdup ("-v9"));
 	g_ptr_array_add (array, g_strdup_printf ("-A%s", manufacturer));
 	g_ptr_array_add (array, g_strdup_printf ("-M%s", model));
 	g_ptr_array_add (array, g_strdup_printf ("-D%s", description_new));
@@ -906,7 +861,6 @@ gcm_calibrate_argyll_display_generate_profile (GcmCalibrateArgyll *calibrate_arg
 		ret = FALSE;
 		goto out;
 	}
-#ifdef HAVE_VTE
 	if (priv->response == GTK_RESPONSE_REJECT) {
 		gchar *vte_text;
 		vte_text = vte_terminal_get_text (VTE_TERMINAL(priv->terminal), NULL, NULL, NULL);
@@ -918,7 +872,7 @@ gcm_calibrate_argyll_display_generate_profile (GcmCalibrateArgyll *calibrate_arg
 		ret = FALSE;
 		goto out;
 	}
-#endif
+
 out:
 	if (array != NULL)
 		g_ptr_array_unref (array);
@@ -1099,10 +1053,7 @@ gcm_calibrate_argyll_device_measure (GcmCalibrateArgyll *calibrate_argyll, GErro
 	filename = g_strdup_printf ("%s.tif", basename);
 
 	/* setup the command */
-#ifdef FIXED_ARGYLL
-	g_ptr_array_add (array, g_strdup (command));
-#endif
-	g_ptr_array_add (array, g_strdup ("-v"));
+	g_ptr_array_add (array, g_strdup ("-v9"));
 	g_ptr_array_add (array, g_strdup ("-p"));
 	g_ptr_array_add (array, g_strdup ("-a"));
 	g_ptr_array_add (array, g_strdup (filename));
@@ -1128,7 +1079,6 @@ gcm_calibrate_argyll_device_measure (GcmCalibrateArgyll *calibrate_argyll, GErro
 		ret = FALSE;
 		goto out;
 	}
-#ifdef HAVE_VTE
 	if (priv->response == GTK_RESPONSE_REJECT) {
 		gchar *vte_text;
 		vte_text = vte_terminal_get_text (VTE_TERMINAL(priv->terminal), NULL, NULL, NULL);
@@ -1140,7 +1090,6 @@ gcm_calibrate_argyll_device_measure (GcmCalibrateArgyll *calibrate_argyll, GErro
 		ret = FALSE;
 		goto out;
 	}
-#endif
 out:
 	g_free (filename);
 	g_free (command);
@@ -1217,10 +1166,7 @@ gcm_calibrate_argyll_device_generate_profile (GcmCalibrateArgyll *calibrate_argy
 	array = g_ptr_array_new_with_free_func (g_free);
 
 	/* setup the command */
-#ifdef FIXED_ARGYLL
-	g_ptr_array_add (array, g_strdup (command));
-#endif
-	g_ptr_array_add (array, g_strdup ("-v"));
+	g_ptr_array_add (array, g_strdup ("-v9"));
 	g_ptr_array_add (array, g_strdup_printf ("-A%s", manufacturer));
 	g_ptr_array_add (array, g_strdup_printf ("-M%s", model));
 	g_ptr_array_add (array, g_strdup_printf ("-D%s", description_tmp));
@@ -1253,7 +1199,6 @@ gcm_calibrate_argyll_device_generate_profile (GcmCalibrateArgyll *calibrate_argy
 		ret = FALSE;
 		goto out;
 	}
-#ifdef HAVE_VTE
 	if (priv->response == GTK_RESPONSE_REJECT) {
 		gchar *vte_text;
 		vte_text = vte_terminal_get_text (VTE_TERMINAL(priv->terminal), NULL, NULL, NULL);
@@ -1265,7 +1210,6 @@ gcm_calibrate_argyll_device_generate_profile (GcmCalibrateArgyll *calibrate_argy
 		ret = FALSE;
 		goto out;
 	}
-#endif
 out:
 	if (array != NULL)
 		g_ptr_array_unref (array);
@@ -1440,118 +1384,6 @@ out:
 	return ret;
 }
 
-/**
- * gcm_calibrate_argyll_spotread_read_chart:
- **/
-static gboolean
-gcm_calibrate_argyll_spotread_read_chart (GcmCalibrateArgyll *calibrate_argyll, GError **error)
-{
-	gboolean ret = TRUE;
-	GcmCalibrateArgyllPrivate *priv = calibrate_argyll->priv;
-	gchar *command = NULL;
-	gchar **argv = NULL;
-	GPtrArray *array = NULL;
-	const gchar *title;
-	const gchar *message;
-
-	/* get correct name of the command */
-	command = gcm_calibrate_argyll_get_tool_filename ("spotread", error);
-	if (command == NULL) {
-		ret = FALSE;
-		goto out;
-	}
-
-	/* TRANSLATORS: title, setting up the photospectromiter */
-	title = _("Setting up device");
-	/* TRANSLATORS: dialog message */
-	message = _("Setting up the device to read a spot color…");
-
-	/* push new messages into the UI */
-	gcm_calibrate_dialog_show (priv->calibrate_dialog, GCM_CALIBRATE_DIALOG_TAB_GENERIC, title, message);
-	gcm_calibrate_dialog_set_show_button_ok (priv->calibrate_dialog, FALSE);
-	gcm_calibrate_dialog_set_show_expander (priv->calibrate_dialog, TRUE);
-
-	/* reset flag so we exit after the single spotread */
-	priv->done_spot_read = FALSE;
-
-	/* argument array */
-	array = g_ptr_array_new_with_free_func (g_free);
-
-	/* setup the command */
-#ifdef FIXED_ARGYLL
-	g_ptr_array_add (array, g_strdup (command));
-#endif
-	g_ptr_array_add (array, g_strdup ("-v"));
-	if (priv->done_calibrate)
-		g_ptr_array_add (array, g_strdup ("-N"));
-	argv = gcm_utils_ptr_array_to_strv (array);
-	gcm_calibrate_argyll_debug_argv (command, argv);
-
-	/* start up the command */
-	ret = gcm_calibrate_argyll_fork_command (calibrate_argyll, argv, error);
-	if (!ret)
-		goto out;
-
-	/* wait until finished */
-	g_main_loop_run (priv->loop);
-
-	/* get result */
-	if (priv->response == GTK_RESPONSE_CANCEL) {
-		g_set_error_literal (error,
-				     GCM_CALIBRATE_ERROR,
-				     GCM_CALIBRATE_ERROR_USER_ABORT,
-				     "calibration was cancelled");
-		ret = FALSE;
-		goto out;
-	}
-#ifdef HAVE_VTE
-	if (priv->response == GTK_RESPONSE_REJECT) {
-		gchar *vte_text;
-		vte_text = vte_terminal_get_text (VTE_TERMINAL(priv->terminal), NULL, NULL, NULL);
-		g_set_error (error,
-			     GCM_CALIBRATE_ERROR,
-			     GCM_CALIBRATE_ERROR_INTERNAL,
-			     "command failed to run successfully: %s", vte_text);
-		g_free (vte_text);
-		ret = FALSE;
-		goto out;
-	}
-#endif
-out:
-	if (array != NULL)
-		g_ptr_array_unref (array);
-	g_free (command);
-	g_strfreev (argv);
-	return ret;
-}
-
-/**
- * gcm_calibrate_argyll_spotread:
- **/
-static gboolean
-gcm_calibrate_argyll_spotread (GcmCalibrate *calibrate, GtkWindow *window, GError **error)
-{
-	GcmCalibrateArgyll *calibrate_argyll = GCM_CALIBRATE_ARGYLL(calibrate);
-	GcmCalibrateArgyllPrivate *priv = calibrate_argyll->priv;
-	gboolean ret;
-
-	/* set modal windows up correctly */
-	gcm_calibrate_dialog_set_move_window (priv->calibrate_dialog, FALSE);
-	gcm_calibrate_dialog_set_window (priv->calibrate_dialog, window);
-
-	/* step 3 */
-	ret = gcm_calibrate_argyll_spotread_read_chart (calibrate_argyll, error);
-	if (!ret)
-		goto out;
-
-	/* step 5 */
-	ret = gcm_calibrate_argyll_remove_temp_files (calibrate_argyll, error);
-	if (!ret)
-		goto out;
-out:
-	return ret;
-}
-
 /**
  * gcm_calibrate_argyll_get_colorimeter_target:
  **/
@@ -1625,21 +1457,16 @@ gcm_calibrate_argyll_display_generate_targets (GcmCalibrateArgyll *calibrate_arg
 	array = g_ptr_array_new_with_free_func (g_free);
 
 	/* setup the command */
-#ifdef FIXED_ARGYLL
-	g_ptr_array_add (array, g_strdup (command));
-#endif
 	g_ptr_array_add (array, g_strdup ("-v"));
 
 	/* target instrument */
 	g_ptr_array_add (array, g_strdup_printf ("-i%s", gcm_calibrate_argyll_get_colorimeter_target (calibrate_argyll)));
 
-#ifdef USE_DOUBLE_DENSITY
 	/* use double density */
 	if (colorimeter_kind == GCM_COLORIMETER_KIND_COLOR_MUNKI ||
 	    colorimeter_kind == GCM_COLORIMETER_KIND_SPECTRO_SCAN) {
 		g_ptr_array_add (array, g_strdup ("-h"));
 	}
-#endif
 
 	/* 8 bit TIFF 300 dpi */
 	g_ptr_array_add (array, g_strdup ("-t300"));
@@ -1668,7 +1495,6 @@ gcm_calibrate_argyll_display_generate_targets (GcmCalibrateArgyll *calibrate_arg
 		ret = FALSE;
 		goto out;
 	}
-#ifdef HAVE_VTE
 	if (priv->response == GTK_RESPONSE_REJECT) {
 		gchar *vte_text;
 		vte_text = vte_terminal_get_text (VTE_TERMINAL(priv->terminal), NULL, NULL, NULL);
@@ -1680,7 +1506,6 @@ gcm_calibrate_argyll_display_generate_targets (GcmCalibrateArgyll *calibrate_arg
 		ret = FALSE;
 		goto out;
 	}
-#endif
 out:
 	if (array != NULL)
 		g_ptr_array_unref (array);
@@ -2216,7 +2041,6 @@ out:
 	return ret;
 }
 
-#ifdef HAVE_VTE
 /**
  * gcm_calibrate_argyll_exit_cb:
  **/
@@ -2265,12 +2089,7 @@ gcm_calibrate_argyll_interaction_attach (GcmCalibrateArgyll *calibrate_argyll)
 	/* different tools assume the device is not on the screen */
 	if (priv->already_on_window) {
 		egg_debug ("VTE: already on screen so faking keypress");
-		priv->keypress_id = g_timeout_add_seconds (1,
-							   (GSourceFunc) gcm_calibrate_argyll_timeout_cb,
-							   calibrate_argyll);
-#if GLIB_CHECK_VERSION(2,25,8)
-		g_source_set_name_by_id (priv->keypress_id, "[GcmCalibrateArgyll] keypress faker");
-#endif
+		g_timeout_add_seconds (1, (GSourceFunc) gcm_calibrate_argyll_timeout_cb, calibrate_argyll);
 		goto out;
 	}
 
@@ -2365,9 +2184,6 @@ gcm_calibrate_argyll_interaction_calibrate (GcmCalibrateArgyll *calibrate_argyll
 	/* assume it's no longer on the window */
 	priv->already_on_window = FALSE;
 
-	/* assume it was done correctly */
-	priv->done_calibrate = TRUE;
-
 	/* set state */
 	priv->argyllcms_ok = " ";
 	priv->state = GCM_CALIBRATE_ARGYLL_STATE_WAITING_FOR_STDIN;
@@ -2395,10 +2211,10 @@ gcm_calibrate_argyll_interaction_surface (GcmCalibrateArgyll *calibrate_argyll)
 
 	if (filename != NULL) {
 		/* TRANSLATORS: this is when the user has to change a setting on the sensor, and we're showing a picture */
-		message = _("Please set the measuring instrument to screen mode like the image below.");
+		message = _("Please set the measuring instrument to screen mode like the image below, and ensure it is attached to the screen.");
 	} else {
 		/* TRANSLATORS: this is when the user has to change a setting on the sensor */
-		message = _("Please set the measuring instrument to screen mode.");
+		message = _("Please set the measuring instrument to screen mode, and ensure it is attached to the screen.");
 	}
 
 	/* push new messages into the UI */
@@ -2512,27 +2328,6 @@ gcm_calibrate_argyll_process_output_cmd (GcmCalibrateArgyll *calibrate_argyll, c
 		goto out;
 	}
 
-	/* spot read result */
-	found = g_strstr_len (line, -1, "Result is XYZ");
-	if (found != NULL) {
-		GcmXyz *xyz;
-		egg_warning ("line=%s", line);
-		split = g_strsplit (line, " ", -1);
-		xyz = gcm_xyz_new ();
-		g_object_set (xyz,
-			      "cie-x", g_ascii_strtod (split[4], NULL),
-			      "cie-y", g_ascii_strtod (split[5], NULL),
-			      "cie-z", g_ascii_strtod (split[6], NULL),
-			      NULL);
-		g_object_set (calibrate_argyll,
-			      "xyz", xyz,
-			      NULL);
-		priv->done_spot_read = TRUE;
-		gcm_calibrate_dialog_response (priv->calibrate_dialog, GTK_RESPONSE_CANCEL);
-		g_object_unref (xyz);
-		goto out;
-	}
-
 	/* error */
 	found = g_strstr_len (line, -1, "Error - ");
 	if (found != NULL) {
@@ -2652,38 +2447,6 @@ gcm_calibrate_argyll_process_output_cmd (GcmCalibrateArgyll *calibrate_argyll, c
 		goto out;
 	}
 
-	/* reading spot */
-	if (g_str_has_prefix (line, "Place instrument on spot to be measured")) {
-		if (!priv->done_spot_read)
-			vte_terminal_feed_child (VTE_TERMINAL(priv->terminal), " ", 1);
-		gcm_calibrate_dialog_hide (priv->calibrate_dialog);
-		goto out;
-	}
-
-
-	/* reading strip */
-	if (g_str_has_prefix (line, "Spot read failed due to misread")) {
-
-		/* TRANSLATORS: title, the calibration failed */
-		title = _("Device Error");
-
-		/* TRANSLATORS: message, the sample was not read correctly */
-		message = _("The device could not measure the color spot correctly.");
-
-		/* push new messages into the UI */
-		gcm_calibrate_dialog_show (priv->calibrate_dialog, GCM_CALIBRATE_DIALOG_TAB_GENERIC, title, message);
-		gcm_calibrate_dialog_set_show_button_ok (priv->calibrate_dialog, TRUE);
-		gcm_calibrate_dialog_set_show_expander (priv->calibrate_dialog, TRUE);
-
-		/* TRANSLATORS: button */
-		gcm_calibrate_dialog_set_button_ok_id (priv->calibrate_dialog, _("Retry"));
-
-		/* set state */
-		priv->argyllcms_ok = " ";
-		priv->state = GCM_CALIBRATE_ARGYLL_STATE_WAITING_FOR_STDIN;
-		goto out;
-	}
-
 	/* reading strip */
 	if (g_str_has_prefix (line, "Ready to read strip pass ")) {
 
@@ -2724,9 +2487,7 @@ out:
 		g_string_free (string, TRUE);
 	return ret;
 }
-#endif
 
-#ifdef HAVE_VTE
 /**
  * gcm_calibrate_argyll_selection_func_cb:
  **/
@@ -2777,7 +2538,6 @@ gcm_calibrate_argyll_cursor_moved_cb (VteTerminal *terminal, GcmCalibrateArgyll
 	g_free (output);
 	g_strfreev (split);
 }
-#endif
 
 /**
  * gcm_calibrate_argyll_response_cb:
@@ -2796,9 +2556,7 @@ gcm_calibrate_argyll_response_cb (GtkWidget *widget, GtkResponseType response, G
 		/* send input if waiting */
 		if (priv->state == GCM_CALIBRATE_ARGYLL_STATE_WAITING_FOR_STDIN) {
 			egg_debug ("sending '%s' to argyll", priv->argyllcms_ok);
-#ifdef HAVE_VTE
 			vte_terminal_feed_child (VTE_TERMINAL(priv->terminal), priv->argyllcms_ok, 1);
-#endif
 			gcm_calibrate_dialog_pop (priv->calibrate_dialog);
 			priv->state = GCM_CALIBRATE_ARGYLL_STATE_RUNNING;
 		}
@@ -2818,9 +2576,7 @@ gcm_calibrate_argyll_response_cb (GtkWidget *widget, GtkResponseType response, G
 		/* send input if waiting */
 		if (priv->state == GCM_CALIBRATE_ARGYLL_STATE_WAITING_FOR_STDIN) {
 			egg_debug ("sending 'Q' to argyll");
-#ifdef HAVE_VTE
 			vte_terminal_feed_child (VTE_TERMINAL(priv->terminal), "Q", 1);
-#endif
 			priv->state = GCM_CALIBRATE_ARGYLL_STATE_RUNNING;
 		}
 
@@ -2830,9 +2586,6 @@ gcm_calibrate_argyll_response_cb (GtkWidget *widget, GtkResponseType response, G
 			priv->state = GCM_CALIBRATE_ARGYLL_STATE_RUNNING;
 		}
 
-		/* hide the window */
-		gcm_calibrate_dialog_hide (priv->calibrate_dialog);
-
 		/* stop loop */
 		if (g_main_loop_is_running (priv->loop))
 			g_main_loop_quit (priv->loop);
@@ -2894,32 +2647,6 @@ gcm_calibrate_argyll_status_changed_cb (GcmPrint *print, GtkPrintStatus status,
 	gcm_calibrate_dialog_set_show_expander (priv->calibrate_dialog, FALSE);
 }
 
-/**
- * gcm_calibrate_argyll_get_property:
- **/
-static void
-gcm_calibrate_argyll_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec)
-{
-	switch (prop_id) {
-	default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-		break;
-	}
-}
-
-/**
- * gcm_calibrate_argyll_set_property:
- **/
-static void
-gcm_calibrate_argyll_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec)
-{
-	switch (prop_id) {
-	default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-		break;
-	}
-}
-
 /**
  * gcm_calibrate_argyll_class_init:
  **/
@@ -2929,14 +2656,11 @@ gcm_calibrate_argyll_class_init (GcmCalibrateArgyllClass *klass)
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 	GcmCalibrateClass *parent_class = GCM_CALIBRATE_CLASS (klass);
 	object_class->finalize = gcm_calibrate_argyll_finalize;
-	object_class->get_property = gcm_calibrate_argyll_get_property;
-	object_class->set_property = gcm_calibrate_argyll_set_property;
 
 	/* setup klass links */
 	parent_class->calibrate_display = gcm_calibrate_argyll_display;
 	parent_class->calibrate_device = gcm_calibrate_argyll_device;
 	parent_class->calibrate_printer = gcm_calibrate_argyll_printer;
-	parent_class->calibrate_spotread = gcm_calibrate_argyll_spotread;
 
 	g_type_class_add_private (klass, sizeof (GcmCalibrateArgyllPrivate));
 }
@@ -2953,7 +2677,6 @@ gcm_calibrate_argyll_init (GcmCalibrateArgyll *calibrate_argyll)
 	calibrate_argyll->priv->vte_previous_row = 0;
 	calibrate_argyll->priv->vte_previous_col = 0;
 	calibrate_argyll->priv->already_on_window = FALSE;
-	calibrate_argyll->priv->done_calibrate = FALSE;
 	calibrate_argyll->priv->state = GCM_CALIBRATE_ARGYLL_STATE_IDLE;
 	calibrate_argyll->priv->print = gcm_print_new ();
 	g_signal_connect (calibrate_argyll->priv->print, "status-changed",
@@ -2966,7 +2689,6 @@ gcm_calibrate_argyll_init (GcmCalibrateArgyll *calibrate_argyll)
 	calibrate_argyll->priv->screen = gcm_screen_new ();
 
 	/* add vte widget */
-#ifdef HAVE_VTE
 	calibrate_argyll->priv->terminal = vte_terminal_new ();
 	vte_terminal_set_size (VTE_TERMINAL(calibrate_argyll->priv->terminal), 80, 10);
 	g_signal_connect (calibrate_argyll->priv->terminal, "child-exited",
@@ -2975,7 +2697,6 @@ gcm_calibrate_argyll_init (GcmCalibrateArgyll *calibrate_argyll)
 			  G_CALLBACK (gcm_calibrate_argyll_cursor_moved_cb), calibrate_argyll);
 	gcm_calibrate_dialog_pack_details (calibrate_argyll->priv->calibrate_dialog,
 					   calibrate_argyll->priv->terminal);
-#endif
 }
 
 /**
@@ -2996,22 +2717,9 @@ gcm_calibrate_argyll_finalize (GObject *object)
 		g_main_loop_run (priv->loop);
 	}
 
-#ifdef HAVE_VTE
-	/* we don't care if the VTE widget redraws now */
-	g_signal_handlers_disconnect_by_func (calibrate_argyll->priv->terminal,
-					      G_CALLBACK (gcm_calibrate_argyll_exit_cb),
-					      calibrate_argyll);
-	g_signal_handlers_disconnect_by_func (calibrate_argyll->priv->terminal,
-					      G_CALLBACK (gcm_calibrate_argyll_cursor_moved_cb),
-					      calibrate_argyll);
-#endif
-
 	/* hide */
 	gcm_calibrate_dialog_hide (priv->calibrate_dialog);
 
-	if (priv->keypress_id != 0)
-		g_source_remove (priv->keypress_id);
-
 	g_main_loop_unref (priv->loop);
 	g_object_unref (priv->screen);
 	g_object_unref (priv->calibrate_dialog);
