@@ -88,10 +88,10 @@ static guint signals[SIGNAL_LAST] = { 0 };
 G_DEFINE_TYPE (GcmCalibrateDialog, gcm_calibrate_dialog, G_TYPE_OBJECT)
 
 /**
- * gcm_calibrate_dialog_response:
+ * gcm_calibrate_dialog_emit_response:
  **/
-void
-gcm_calibrate_dialog_response (GcmCalibrateDialog *calibrate_dialog, GtkResponseType response)
+static void
+gcm_calibrate_dialog_emit_response (GcmCalibrateDialog *calibrate_dialog, GtkResponseType response)
 {
 	calibrate_dialog->priv->response = response;
 	g_signal_emit (calibrate_dialog, signals[SIGNAL_RESPONSE], 0, response);
@@ -108,7 +108,7 @@ static void
 gcm_calibrate_dialog_button_clicked_lcd_cb (GtkWidget *widget, GcmCalibrateDialog *calibrate_dialog)
 {
 	calibrate_dialog->priv->device_kind = GCM_CALIBRATE_DEVICE_KIND_LCD;
-	gcm_calibrate_dialog_response (calibrate_dialog, GTK_RESPONSE_OK);
+	gcm_calibrate_dialog_emit_response (calibrate_dialog, GTK_RESPONSE_OK);
 }
 
 /**
@@ -118,7 +118,7 @@ static void
 gcm_calibrate_dialog_button_clicked_crt_cb (GtkWidget *widget, GcmCalibrateDialog *calibrate_dialog)
 {
 	calibrate_dialog->priv->device_kind = GCM_CALIBRATE_DEVICE_KIND_CRT;
-	gcm_calibrate_dialog_response (calibrate_dialog, GTK_RESPONSE_OK);
+	gcm_calibrate_dialog_emit_response (calibrate_dialog, GTK_RESPONSE_OK);
 }
 
 /**
@@ -128,7 +128,7 @@ static void
 gcm_calibrate_dialog_button_clicked_projector_cb (GtkWidget *widget, GcmCalibrateDialog *calibrate_dialog)
 {
 	calibrate_dialog->priv->device_kind = GCM_CALIBRATE_DEVICE_KIND_PROJECTOR;
-	gcm_calibrate_dialog_response (calibrate_dialog, GTK_RESPONSE_OK);
+	gcm_calibrate_dialog_emit_response (calibrate_dialog, GTK_RESPONSE_OK);
 }
 
 /**
@@ -138,7 +138,7 @@ static void
 gcm_calibrate_dialog_button_clicked_print_local_cb (GtkWidget *widget, GcmCalibrateDialog *calibrate_dialog)
 {
 	calibrate_dialog->priv->print_kind = GCM_CALIBRATE_PRINT_KIND_LOCAL;
-	gcm_calibrate_dialog_response (calibrate_dialog, GTK_RESPONSE_OK);
+	gcm_calibrate_dialog_emit_response (calibrate_dialog, GTK_RESPONSE_OK);
 }
 
 /**
@@ -148,7 +148,7 @@ static void
 gcm_calibrate_dialog_button_clicked_print_generate_cb (GtkWidget *widget, GcmCalibrateDialog *calibrate_dialog)
 {
 	calibrate_dialog->priv->print_kind = GCM_CALIBRATE_PRINT_KIND_GENERATE;
-	gcm_calibrate_dialog_response (calibrate_dialog, GTK_RESPONSE_OK);
+	gcm_calibrate_dialog_emit_response (calibrate_dialog, GTK_RESPONSE_OK);
 }
 
 /**
@@ -158,7 +158,7 @@ static void
 gcm_calibrate_dialog_button_clicked_print_analyze_cb (GtkWidget *widget, GcmCalibrateDialog *calibrate_dialog)
 {
 	calibrate_dialog->priv->print_kind = GCM_CALIBRATE_PRINT_KIND_ANALYZE;
-	gcm_calibrate_dialog_response (calibrate_dialog, GTK_RESPONSE_OK);
+	gcm_calibrate_dialog_emit_response (calibrate_dialog, GTK_RESPONSE_OK);
 }
 
 /**
@@ -168,7 +168,7 @@ static void
 gcm_calibrate_dialog_button_clicked_precision_short_cb (GtkWidget *widget, GcmCalibrateDialog *calibrate_dialog)
 {
 	calibrate_dialog->priv->precision = GCM_CALIBRATE_PRECISION_SHORT;
-	gcm_calibrate_dialog_response (calibrate_dialog, GTK_RESPONSE_OK);
+	gcm_calibrate_dialog_emit_response (calibrate_dialog, GTK_RESPONSE_OK);
 }
 
 /**
@@ -178,7 +178,7 @@ static void
 gcm_calibrate_dialog_button_clicked_precision_normal_cb (GtkWidget *widget, GcmCalibrateDialog *calibrate_dialog)
 {
 	calibrate_dialog->priv->precision = GCM_CALIBRATE_PRECISION_NORMAL;
-	gcm_calibrate_dialog_response (calibrate_dialog, GTK_RESPONSE_OK);
+	gcm_calibrate_dialog_emit_response (calibrate_dialog, GTK_RESPONSE_OK);
 }
 
 /**
@@ -188,7 +188,7 @@ static void
 gcm_calibrate_dialog_button_clicked_precision_long_cb (GtkWidget *widget, GcmCalibrateDialog *calibrate_dialog)
 {
 	calibrate_dialog->priv->precision = GCM_CALIBRATE_PRECISION_LONG;
-	gcm_calibrate_dialog_response (calibrate_dialog, GTK_RESPONSE_OK);
+	gcm_calibrate_dialog_emit_response (calibrate_dialog, GTK_RESPONSE_OK);
 }
 
 /**
@@ -197,7 +197,7 @@ gcm_calibrate_dialog_button_clicked_precision_long_cb (GtkWidget *widget, GcmCal
 static void
 gcm_calibrate_dialog_button_clicked_ok_cb (GtkWidget *widget, GcmCalibrateDialog *calibrate_dialog)
 {
-	gcm_calibrate_dialog_response (calibrate_dialog, GTK_RESPONSE_OK);
+	gcm_calibrate_dialog_emit_response (calibrate_dialog, GTK_RESPONSE_OK);
 }
 
 /**
@@ -206,7 +206,7 @@ gcm_calibrate_dialog_button_clicked_ok_cb (GtkWidget *widget, GcmCalibrateDialog
 static void
 gcm_calibrate_dialog_button_clicked_cancel_cb (GtkWidget *widget, GcmCalibrateDialog *calibrate_dialog)
 {
-	gcm_calibrate_dialog_response (calibrate_dialog, GTK_RESPONSE_CANCEL);
+	gcm_calibrate_dialog_emit_response (calibrate_dialog, GTK_RESPONSE_CANCEL);
 }
 
 /**
@@ -503,7 +503,18 @@ gcm_calibrate_dialog_set_show_expander (GcmCalibrateDialog *calibrate_dialog, gb
 void
 gcm_calibrate_dialog_set_move_window (GcmCalibrateDialog *calibrate_dialog, gboolean move_window)
 {
+	gint x, y;
+	GtkWidget *widget;
+	GcmCalibrateDialogPrivate *priv = calibrate_dialog->priv;
+
 	calibrate_dialog->priv->move_window = move_window;
+
+	/* move the dialog out of the way, so the grey square doesn't cover it */
+	widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "dialog_calibrate"));
+	if (move_window) {
+		gtk_window_get_position (GTK_WINDOW (widget), &x, &y);
+		gtk_window_move (GTK_WINDOW (widget), 10, y);
+	}
 }
 
 /**
@@ -512,7 +523,7 @@ gcm_calibrate_dialog_set_move_window (GcmCalibrateDialog *calibrate_dialog, gboo
 static gboolean
 gcm_calibrate_dialog_delete_event_cb (GtkWidget *widget, GdkEvent *event, GcmCalibrateDialog *calibrate_dialog)
 {
-	gcm_calibrate_dialog_response (calibrate_dialog, GTK_RESPONSE_CANCEL);
+	gcm_calibrate_dialog_emit_response (calibrate_dialog, GTK_RESPONSE_CANCEL);
 	return FALSE;
 }
 
@@ -856,3 +867,30 @@ gcm_calibrate_dialog_new (void)
 	return GCM_CALIBRATE_DIALOG (gcm_calibrate_dialog_object);
 }
 
+/***************************************************************************
+ ***                          MAKE CHECK TESTS                           ***
+ ***************************************************************************/
+#ifdef EGG_TEST
+#include "egg-test.h"
+
+void
+gcm_calibrate_dialog_test (EggTest *test)
+{
+	GcmCalibrateDialog *calibrate_dialog;
+//	gboolean ret;
+//	GError *error = NULL;
+
+	if (!egg_test_start (test, "GcmCalibrateDialog"))
+		return;
+
+	/************************************************************/
+	egg_test_title (test, "get a calibrate_dialog object");
+	calibrate_dialog = gcm_calibrate_dialog_new ();
+	egg_test_assert (test, calibrate_dialog != NULL);
+
+	g_object_unref (calibrate_dialog);
+
+	egg_test_end (test);
+}
+#endif
+
